===================================================
Apax: Atomistic learned Potentials in JAX!
===================================================


`Apax` is a high-performance, extendable package for training of and inference with atomistic neural networks., most prominently the Gaussian Moment Neural Network.
It is based on `JAX <https://jax.readthedocs.io/en/latest/>`_ and uses `JaxMD <https://github.com/jax-md/jax-md>`_ as a molecular dynamics engine.

.. toctree::
   :hidden:

   getting_started/index
   _tutorials/index
   configs/index
   modules/index
